---
name: Bug report
about: Create a report to help us improve
title: ""
labels: bug
assignees: ""
---

**Issue**

Describe what's the expected behaviour and what you're observing.

**Environment**

Provide at least:

- OS:
- `pip list` of the host python where `virtualenv` is installed:

  ```console

  ```

**Output of the virtual environment creation**

Make sure to run the creation with `-vvv --with-traceback`:

```console

```
